==> zio-aws-mediatailor_3-5.17.103.1-sources.jar: zio/aws/mediatailor/model/HttpPackageConfiguration.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class HttpPackageConfiguration(
    path: __string,
    sourceGroup: __string,
    `type`: zio.aws.mediatailor.model.Type
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.HttpPackageConfiguration = {
    import HttpPackageConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.HttpPackageConfiguration
      .builder()
      .path(__string.unwrap(path): java.lang.String)
      .sourceGroup(__string.unwrap(sourceGroup): java.lang.String)
      .`type`(`type`.unwrap)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.HttpPackageConfiguration.ReadOnly =
    zio.aws.mediatailor.model.HttpPackageConfiguration.wrap(buildAwsValue())
}
object HttpPackageConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.HttpPackageConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.HttpPackageConfiguration =
      zio.aws.mediatailor.model
        .HttpPackageConfiguration(path, sourceGroup, `type`)
    def path: __string
    def sourceGroup: __string
    def `type`: zio.aws.mediatailor.model.Type
    def getPath: ZIO[Any, Nothing, __string] = ZIO.succeed(path)
    def getSourceGroup: ZIO[Any, Nothing, __string] = ZIO.succeed(sourceGroup)
    def getType: ZIO[Any, Nothing, zio.aws.mediatailor.model.Type] =
      ZIO.succeed(`type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.HttpPackageConfiguration
  ) extends zio.aws.mediatailor.model.HttpPackageConfiguration.ReadOnly {
    override val path: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.path())
    override val sourceGroup: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.sourceGroup())
    override val `type`: zio.aws.mediatailor.model.Type =
      zio.aws.mediatailor.model.Type.wrap(impl.`type`())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.HttpPackageConfiguration
  ): zio.aws.mediatailor.model.HttpPackageConfiguration.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-mediatailor_3-5.19.8.1-sources.jar: zio/aws/mediatailor/model/HttpPackageConfiguration.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class HttpPackageConfiguration(
    path: __string,
    sourceGroup: __string,
    `type`: zio.aws.mediatailor.model.Type
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.HttpPackageConfiguration = {
    import HttpPackageConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.HttpPackageConfiguration
      .builder()
      .path(path: java.lang.String)
      .sourceGroup(sourceGroup: java.lang.String)
      .`type`(`type`.unwrap)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.HttpPackageConfiguration.ReadOnly =
    zio.aws.mediatailor.model.HttpPackageConfiguration.wrap(buildAwsValue())
}
object HttpPackageConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.HttpPackageConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.HttpPackageConfiguration =
      zio.aws.mediatailor.model
        .HttpPackageConfiguration(path, sourceGroup, `type`)
    def path: __string
    def sourceGroup: __string
    def `type`: zio.aws.mediatailor.model.Type
    def getPath: ZIO[Any, Nothing, __string] = ZIO.succeed(path)
    def getSourceGroup: ZIO[Any, Nothing, __string] = ZIO.succeed(sourceGroup)
    def getType: ZIO[Any, Nothing, zio.aws.mediatailor.model.Type] =
      ZIO.succeed(`type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.HttpPackageConfiguration
  ) extends zio.aws.mediatailor.model.HttpPackageConfiguration.ReadOnly {
    override val path: __string = impl.path(): __string
    override val sourceGroup: __string = impl.sourceGroup(): __string
    override val `type`: zio.aws.mediatailor.model.Type =
      zio.aws.mediatailor.model.Type.wrap(impl.`type`())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.HttpPackageConfiguration
  ): zio.aws.mediatailor.model.HttpPackageConfiguration.ReadOnly = new Wrapper(
    impl
  )
}
